@@ -19,14 +19,11 @@
 */
 
 #include "kgameconnectdialog.h"
-
-#include <knuminput.h>
-#include <klocale.h>
-#include <kdebug.h>
+#include "kfourinline_debug.h"
+#include <KLocalizedString>
 #include <klineedit.h>
 
 #include <QComboBox>
-#include <QLayout>
 #include <qradiobutton.h>
 #include <QLabel>
 #include <QVBoxLayout>
@@ -35,6 +32,7 @@
 #include <dnssd/servicebrowser.h>
 #include <QPushButton>
 #include <QGroupBox>
+#include <QSpinBox>
 
 class KGameConnectWidgetPrivate
 {
@@ -47,12 +45,12 @@ class KGameConnectWidgetPrivate
 		mBrowser = 0;
 	}
 
-	KIntNumInput* mPort;
+	QSpinBox* mPort;
 	KLineEdit* mHost;
 	QButtonGroup* mButtonGroup;
 	QComboBox *mClientName;
 	QLabel *mClientNameLabel;
-	DNSSD::ServiceBrowser *mBrowser;
+	KDNSSD::ServiceBrowser *mBrowser;
 	QLabel *mServerNameLabel;
 	KLineEdit *mServerName;
 	QString mType;
@@ -69,7 +67,7 @@ KGameConnectWidget::KGameConnectWidget(QWidget* parent) : QWidget(parent)
  d->mButtonGroup = new QButtonGroup(this);
  d->mButtonGroup->setExclusive(true);
  vb->addWidget(box);
- connect(d->mButtonGroup, SIGNAL(buttonClicked(int)), this, SLOT(slotTypeChanged(int)));
+ connect(d->mButtonGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &KGameConnectWidget::slotTypeChanged);
  QRadioButton* buttonCreate = new QRadioButton(i18n("Create a network game"), box);
  boxlay->addWidget(buttonCreate);
  d->mButtonGroup->addButton(buttonCreate,0);
@@ -90,9 +88,9 @@ KGameConnectWidget::KGameConnectWidget(QWidget* parent) : QWidget(parent)
  layout->addWidget(d->mServerName, 0, 1);
  layout->addWidget(d->mClientNameLabel, 1, 0);
  layout->addWidget(d->mClientName, 1, 1);
- connect(d->mClientName,SIGNAL(activated(int)),SLOT(slotGameSelected(int)));
+ connect(d->mClientName, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &KGameConnectWidget::slotGameSelected);
  QLabel* label = new QLabel(i18n("Port to connect to:"), g);
- d->mPort = new KIntNumInput(g);
+ d->mPort = new QSpinBox(g);
  layout->addWidget(label, 2, 0);
  layout->addWidget(d->mPort, 2, 1);
  label = new QLabel(i18n("Host to connect to:"), g);
@@ -101,7 +99,7 @@ KGameConnectWidget::KGameConnectWidget(QWidget* parent) : QWidget(parent)
  layout->addWidget(d->mHost, 3, 1);
 
  QPushButton *button=new QPushButton(i18n("&Start Network"), this);
- connect(button, SIGNAL(clicked()), this, SIGNAL(signalNetworkSetup()));
+ connect(button, &QPushButton::clicked, this, &KGameConnectWidget::signalNetworkSetup);
  vb->addWidget(button);
  // Hide until type is set
  d->mClientName->hide();
@@ -131,8 +129,8 @@ void KGameConnectWidget::setType(const QString& type)
 {
  d->mType = type;
  delete d->mBrowser;
- d->mBrowser = new DNSSD::ServiceBrowser(type);
- connect(d->mBrowser,SIGNAL(finished()),SLOT(slotGamesFound()));
+ d->mBrowser = new KDNSSD::ServiceBrowser(type);
+ connect(d->mBrowser, &KDNSSD::ServiceBrowser::finished, this, &KGameConnectWidget::slotGamesFound);
  d->mBrowser->startBrowse();
  showDnssdControls();
 }
@@ -144,7 +142,7 @@ void KGameConnectWidget::slotGamesFound()
  d->mClientName->clear();
  QStringList names;
  
- QListIterator<DNSSD::RemoteService::Ptr> it(d->mBrowser->services());
+ QListIterator<KDNSSD::RemoteService::Ptr> it(d->mBrowser->services());
  while (it.hasNext())
   names << it.next()->serviceName();
  d->mClientName->addItems(names);
@@ -170,7 +168,7 @@ void KGameConnectWidget::slotGameSelected(int nr)
 {
  if (nr>=(d->mBrowser->services().count()) || nr<0) return;
  if (!d->mHost->isEnabled()) return; // this is server mode, do not overwrite host and port controls
- DNSSD::RemoteService::Ptr srv = d->mBrowser->services()[nr];
+ KDNSSD::RemoteService::Ptr srv = d->mBrowser->services()[nr];
  if (!srv->isResolved() && !srv->resolve()) return;
  d->mHost->setText(srv->hostName());
  d->mPort->setValue(srv->port());
@@ -208,7 +206,7 @@ void KGameConnectWidget::setPort(unsigned short int port)
 void KGameConnectWidget::setDefault(int state)
 {
  if (d->mButtonGroup->button(state) == 0) {
-  kError(11001) << "KGameConnectWidget::setDefault" << state;
+  qCCritical(KFOURINLINE_LOG) << "KGameConnectWidget::setDefault" << state;
   return;
  } 
  d->mButtonGroup->button(state)->setChecked(true);
@@ -226,5 +224,5 @@ void KGameConnectWidget::slotTypeChanged(int t)
  emit signalServerTypeChanged(t);
 }
 
-#include "kgameconnectdialog.moc"
+
 
