@@ -19,7 +19,7 @@
 */
 
 #include "kgamedialogconfig.h"
-
+#include "kfourinline_debug.h"
 #include "kgameconnectdialog.h"
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
@@ -29,19 +29,17 @@
 #include <libkdegamesprivate/kgame/kgameproperty.h>
 
 
-#include <klistwidget.h>
-#include <klocale.h>
-#include <knuminput.h>
-#include <kdialog.h>
+#include <KLocalizedString>
 #include <kmessagebox.h>
 #include <klineedit.h>
 
-#include <QLayout>
 #include <QLabel>
 #include <QPushButton>
 #include <QGroupBox>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+
 
-#include "kgamedialogconfig.moc"
 
 class KGameDialogConfigPrivate
 {
@@ -67,7 +65,7 @@ KGameDialogConfig::KGameDialogConfig(QWidget* parent)
 
 KGameDialogConfig::~KGameDialogConfig()
 {
- kDebug(11001) ;
+ qCDebug(KFOURINLINE_LOG) ;
  delete d;
 }
 
@@ -122,22 +120,19 @@ public:
 KGameDialogNetworkConfig::KGameDialogNetworkConfig(QWidget* parent)
 		: KGameDialogConfig(parent)
 {
-// kDebug(11001) << ": this=" << this;
+// qCDebug(KFOURINLINE_LOG) << ": this=" << this;
  d = new KGameDialogNetworkConfigPrivate();
 
  QVBoxLayout* topLayout = new QVBoxLayout(this);
- topLayout->setMargin( KDialog::marginHint() );
- topLayout->setSpacing( KDialog::spacingHint() );
 
  QHBoxLayout *hb = new QHBoxLayout;
- hb->setSpacing( KDialog::spacingHint() );
  topLayout->addLayout(hb);
 
  d->mNetworkLabel = new QLabel(this);
  hb->addWidget(d->mNetworkLabel);
 
  d->mDisconnectButton=new QPushButton(i18n("Disconnect"),this);
- connect(d->mDisconnectButton, SIGNAL(clicked()), this, SLOT(slotExitConnection()));
+ connect(d->mDisconnectButton, &QPushButton::clicked, this, &KGameDialogNetworkConfig::slotExitConnection);
  hb->addWidget(d->mDisconnectButton);
 
  d->mInitConnection = new QGroupBox(i18n("Network Configuration"), this);
@@ -146,31 +141,30 @@ KGameDialogNetworkConfig::KGameDialogNetworkConfig(QWidget* parent)
 
  d->mConnect = new KGameConnectWidget(d->mInitConnection);
  gboxLay->addWidget(d->mConnect);
- connect(d->mConnect, SIGNAL(signalNetworkSetup()), this, SLOT(slotInitConnection()));
- connect(d->mConnect, SIGNAL(signalServerTypeChanged(int)),
-         this, SIGNAL(signalServerTypeChanged(int)));
+ connect(d->mConnect, &KGameConnectWidget::signalNetworkSetup, this, &KGameDialogNetworkConfig::slotInitConnection);
+ connect(d->mConnect, &KGameConnectWidget::signalServerTypeChanged, this, &KGameDialogNetworkConfig::signalServerTypeChanged);
 
  // Needs to be AFTER the creation of the dialogs
  setConnected(false);
- setDefaultNetworkInfo(QLatin1String( "localhost" ), 7654,true);
+ setDefaultNetworkInfo(QStringLiteral( "localhost" ), 7654,true);
 }
 
 KGameDialogNetworkConfig::~KGameDialogNetworkConfig()
 {
- kDebug(11001) ;
+ qCDebug(KFOURINLINE_LOG) ;
  delete d;
 }
 
 void KGameDialogNetworkConfig::slotExitConnection()
 {
- kDebug(11001) << " !!!!!!!!!!!!!!!!!!!!!!!";
+ qCDebug(KFOURINLINE_LOG) << " !!!!!!!!!!!!!!!!!!!!!!!";
   if (game()) game()->disconnect();
   setConnected(false,false);
 }
 
 void KGameDialogNetworkConfig::slotInitConnection()
 {
- kDebug(11001) ;
+ qCDebug(KFOURINLINE_LOG) ;
  bool connected = false;
  bool master = true;
  unsigned short int port = d->mConnect->port();
@@ -189,8 +183,8 @@ void KGameDialogNetworkConfig::slotInitConnection()
 	}
   // We need to learn about failed connections
   if (game()) {
-     connect(game(), SIGNAL(signalConnectionBroken()),
-      this, SLOT(slotConnectionBroken()));
+     connect(game(), &KGameNetwork::signalConnectionBroken,
+      this, &KGameDialogNetworkConfig::slotConnectionBroken);
   }
  }
  setConnected(connected, master);
@@ -198,7 +192,7 @@ void KGameDialogNetworkConfig::slotInitConnection()
 
 void KGameDialogNetworkConfig::slotConnectionBroken()
 {
-  kDebug(11001) ;
+  qCDebug(KFOURINLINE_LOG) ;
   setConnected(false,false);
   KMessageBox::error(this, i18n("Cannot connect to the network"));
 }
