@@ -21,12 +21,13 @@
 #ifndef __KGAMEPROCESS_H_
 #define __KGAMEPROCESS_H_
 
-#include <QtCore/QObject>
-#include <QFile>
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgame/kgamemessage.h>
 #include <libkdegamesprivate/kgame/kmessageio.h>
 
+#include <QObject>
+#include <QFile>
+
 class KRandomSequence;
 
 class KPlayer;
@@ -112,7 +113,7 @@ class KGameProcess:  public QObject
      * Enters the event loop of the computer process. Does only
      * return on setTerminate(true)!
      */
-    bool exec(int argc, char *argv[]);
+    bool exec();
 
     /**
      * Should the computer process leave its exec function?
@@ -173,13 +174,6 @@ class KGameProcess:  public QObject
      */
     KRandomSequence *random();
 
-  protected:
-    /**
-     * processes the command line argumens to set up the computer player
-     * Pass the argumens exactely as given by main()
-     */
-    void processArgs(int argc, char *argv[]);
-
   protected Q_SLOTS:
     /**
      * A message is received via the interprocess connection. The
